@@ -132,8 +132,7 @@ def pull(
 	lremote = serialize_path(gfp.clean(remote), append_last_slash=directory)
 	lpath = serialize_path(gfp.clean(path), append_last_slash=directory)
 	_command_ = f"rsync -{Formats.Boolean(directory).convert(true='a', false='')}zqt '{alias}:{lremote}' '{lpath}' {exclude_str} {include_str} {delete_str}"
-	#if log_level >= 3: 
-	print(f"Rsync command: [{_command_}].")
+	if log_level >= 3: print(f"Rsync command: [{_command_}].")
 
 	# execute.
 	if command: return _command_
